# Generated by Django 3.0 on 2019-12-10 08:06

from django.db import migrations, models
import djangorestfilemanager.models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('uuid', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('file', models.FileField(storage=djangorestfilemanager.models.MyFileSystemStorage(location='files'), upload_to='files/', verbose_name='File')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('user_name', models.CharField(max_length=100, verbose_name='User name')),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
                ('last_mod_date', models.DateTimeField(auto_now=True, verbose_name='Creation date')),
                ('origin', models.CharField(blank=True, choices=[('RST', 'REST')], default='RST', max_length=3, null=True, verbose_name='Origin')),
                ('type', models.CharField(blank=True, choices=[('DFT', 'Default')], default='DFT', max_length=3, null=True, verbose_name='Type')),
                ('permission', models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Permission')),
                ('share', models.BooleanField(default=False, verbose_name='Share')),
            ],
            options={
                'verbose_name': 'File',
                'verbose_name_plural': 'Files',
            },
        ),
    ]
